from datetime import datetime
from typing import List, Optional, Dict, Any

from janis_core import *
from janis_core.types.common_data_types import File, Int, Boolean, String

Ceasbw_V0_1_0 = CommandToolBuilder(tool="ceasBW", base_command=["ceasBW"], inputs=[ToolInput(tag="in_bed", input_type=File(optional=True), prefix="--bed", doc=InputDocumentation(doc="BED file of ChIP regions.")), ToolInput(tag="in_bigwig", input_type=File(optional=True), prefix="--bigwig", doc=InputDocumentation(doc="BIGWIG file for either wig profiling or genome\nbackground annotation. WARNING: --bg flag must be set\nfor genome background re-annotation.")), ToolInput(tag="in_e_bed", input_type=File(optional=True), prefix="--ebed", doc=InputDocumentation(doc="BED file of extra regions of interest (eg, non-coding\nregions)")), ToolInput(tag="in_gt", input_type=Int(optional=True), prefix="--gt", doc=InputDocumentation(doc="Gene annotation table (eg, a refGene table in sqlite3\ndb format provided through the CEAS web,\nhttp://liulab.dfci.harvard.edu/CEAS/download.html).")), ToolInput(tag="in_name", input_type=File(optional=True), prefix="--name", doc=InputDocumentation(doc="Experiment name. This will be used to name the output\nfiles. If an experiment name is not given, the stem of\nthe input BED file name will be used instead (eg, if\n'peaks.bed', 'peaks' will be used as a name.)")), ToolInput(tag="in_sizes", input_type=Int(optional=True), prefix="--sizes", doc=InputDocumentation(doc="Promoter (also dowsntream) sizes for ChIP region\nannotation. Comma-separated three values or a single\nvalue can be given. If a single value is given, it\nwill be segmented into three equal fractions (ie, 3000\nis equivalent to 1000,2000,3000), DEFAULT:\n1000,2000,3000. WARNING: Values > 10000bp are\nautomatically set to 10000bp.")), ToolInput(tag="in_bi_sizes", input_type=Int(optional=True), prefix="--bisizes", doc=InputDocumentation(doc="Bidirectional-promoter sizes for ChIP region\nannotation Comma-separated two values or a single\nvalue can be given. If a single value is given, it\nwill be segmented into two equal fractions (ie, 5000\nis equivalent to 2500,5000) DEFAULT: 2500,5000bp.\nWARNING: Values > 20000bp are automatically set to\n20000bp.")), ToolInput(tag="in_bg", input_type=Boolean(optional=True), prefix="--bg", doc=InputDocumentation(doc="Run genome BG annotation again. WARNING: This flag is\neffective only if a WIG file is given through -w\n(--wig). Otherwise, ignored.")), ToolInput(tag="in_span", input_type=Int(optional=True), prefix="--span", doc=InputDocumentation(doc="Span from TSS and TTS in the gene-centered annotation.\nChIP regions within this range from TSS and TTS are\nconsidered when calculating the coverage rates in\npromoter and downstream, DEFAULT=3000bp")), ToolInput(tag="in_pf_res", input_type=Int(optional=True), prefix="--pf-res", doc=InputDocumentation(doc="Wig profiling resolution, DEFAULT: 50bp. WARNING:\nValue smaller than the wig interval (resolution) may\ncause aliasing error.")), ToolInput(tag="in_rel_dist", input_type=Int(optional=True), prefix="--rel-dist", doc=InputDocumentation(doc="Relative distance to TSS/TTS in wig profiling,\nDEFAULT: 3000bp")), ToolInput(tag="in_gn_groups", input_type=File(optional=True), prefix="--gn-groups", doc=InputDocumentation(doc="Gene-groups of particular interest in wig profiling.\nEach gene group file must have gene names in the 1st\ncolumn. The file names are separated by commas w/ no\nspace (eg, --gn-groups=top10.txt,bottom10.txt)")), ToolInput(tag="in_gn_group_names", input_type=Int(optional=True), prefix="--gn-group-names", doc=InputDocumentation(doc="The names of the gene groups in --gn-groups. The gene\ngroup names are separated by commas. (eg, --gn-group-\nnames='top 10%,bottom 10%'). These group names appear\nin the legends of the wig profiling plots. If no group\nnames given, the groups are represented as 'Group 1,\nGroup2,...Group n'.")), ToolInput(tag="in_g_name_two", input_type=Boolean(optional=True), prefix="--gname2", doc=InputDocumentation(doc="Whether or not use the 'name2' column of the gene\nannotation table when reading the gene IDs in the\nfiles given through --gn-groups. This flag is\nmeaningful only with --gn-groups.")), ToolInput(tag="in_dump", input_type=Boolean(optional=True), prefix="--dump", doc=InputDocumentation(doc="Whether to save the raw profiles of near TSS, TTS, and\ngene body. The file names have a suffix of 'TSS',\n'TTS', and 'gene' after the name.")), ToolInput(tag="in_length", input_type=Int(optional=True), prefix="--length", doc=InputDocumentation(doc="file contains lenth information of every chroms\n")), ToolInput(tag="in_input_files", input_type=String(), position=0, doc=InputDocumentation(doc=""))], outputs=[], container=None, version="v0.1.0")


if __name__ == "__main__":
    # or "cwl"
    Ceasbw_V0_1_0().translate("wdl", allow_empty_container=True)

